##  Overview
In previous phases, you were able to specify <what> will be affected. In this phase, you will leverage SAP LeanIX for the detailed planning of your organization’s target architecture by further specifying <how> your landscape will be affected by the transformation, leveraging more capabilities of SAP LeanIX Architecture and Road Map Planning. This involves determining when new applications will be introduced, when applications will be phased out, what technology will be replaced etc. With what you will identify gaps and necessary changes to meet the target architecture, explore transformation impacts, and prepare stakeholders for the overall rollout. To achieve this, you will need to use some additional SAP LeanIX features explained in this step.
**Note**
In this step, you will unlock further features of the SAP LeanIX Architecture and Road Map Planning (Previously known as BTM module). The additional features (Transformations and Impacts) enable you to visualize your target (to-be) architecture, showing changes and impacts on a timeline. This sets the foundation to actually execute your transformation in the next phases. Learn here more about how to [use Milestones](https://help.sap.com/docs/leanix/ea/milestones?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to add and manage milestones and realize their value by effectively visualizing them in reports."), [use Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.") and [how Impacts are created](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD "Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.") in SAP LeanIX.
In this phase, do the following:
  1. [Add Transformations and Impacts](https://help.sap.com/docs/leanix/ea/erp-transformation-explore?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bce6b7a4410148b4884bf5ee8b4fa__step_1._add_transformations_and_impacts_with_architecture_and_road_map_planning): Enrich your Inventory by adding Transformations and Impacts with the SAP LeanIX Architecture and Road Map Planning.
  2. [Evaluate Data](https://help.sap.com/docs/leanix/ea/erp-transformation-explore?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bce6b7a4410148b4884bf5ee8b4fa__step_2._evaluate_data): Use enhanced reporting capabilities to visualize the future state, identify gaps from the current state, and establish a clear target architecture.
  3. [Report and Communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-explore?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bce6b7a4410148b4884bf5ee8b4fa__step_3._report_and_communicate): Build on the dashboard you created in the [previous phase](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD "Build high-level transformation scenarios and plan a detailed roadmap."), and add relevant Reports and KPIs for overview and communication.


The following overview gives a "Definition of Done" and milestones that you should achieve in this phase.
Milestones |  KPIs/Reports
---|---
Detailed target architecture (represented by enriched Reporting views showing Transformations and Impacts based on one or more selected Initiatives). |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746f4b07a441014a5e0fc8fc7b22c75_LowRes.png)
Initial target architecture validated; planned Transformations and Impacts identified. | KPI to compare “set” transformations and “completed” transformations for those Projects in scope (view to be added by SAP LeanIX).
Detailed understanding of transformation scenarios. | Project roadmap from phase 2, now enhanced with blocked/blocked by (view to be added by SAP LeanIX).
Management buy-in for chosen transformation scenario (happens based on info in SAP LeanIX, but outside of the tool). | Reflected in Final Transformation Roadmap (decision can be documented on the 1st-Level Initiative Fact Sheet in the Comments tab).


